@@ -12,6 +12,7 @@ class DeviceType(Enum):
     WEATHER = auto()
     VENEER = auto()
     BASIC_LIGHT = auto()
+    CLICK = auto()
     UNKNOWN = auto()
 
     def string(self) -> str:
@@ -32,5 +33,5 @@ class DeviceType(Enum):
         """Get the device type from the Onyx API's type information."""
         try:
             return DeviceType[lower.upper()]
-        except KeyError:
+        except (KeyError, AttributeError):
             return None
